.. _examples:

========
Examples
========

.. toctree::
   :maxdepth: 1

   note_about_examples
   examples_built/reconst_dti
   examples_built/reconst_csa
   examples_built/reconst_dsi
   examples_built/reconst_gqi
   examples_built/tracking_eudx_tensor
   examples_built/tracking_eudx_odf
   examples_built/probabilistic_tracking_odfs
   examples_built/reslice_datasets
   examples_built/segment_quickbundles
   examples_built/streamline_formats
   examples_built/warp_streamlines

.. In order to build the examples, you'll need (on Debian)
    sudo apt-get install python-tables python-matplotib python-vtk
